/*
TASK: expression
LANG: C++
KEYW: Dynamic Programming, Bignum (addition)
*/
#include <iostream>
#include <vector>
#include <cstdio>
#include <ctime>
#include <algorithm>
#include <numeric>
#include <iomanip>
#include <cmath>
#include <cstring>
#include <string>
#include <cassert>
#include <queue>
#include <set>

typedef long long ll;

const ll LLINF = 1LL << 60;
const int INF = 1 << 30;
const double EPS = 1e-9;

using namespace std;

const int MAXN = 1 << 7;
const int BASE = 10;
const int BASELOG = 1;
const int MAXDIG = 30;

struct bignum{
    ll num[MAXDIG];
    
    bignum( ll init = 0 ){
        fill( num , num + MAXDIG , 0 );
        
        int at = 0;
        
        while( init )
            num[at++] = init % BASE, init /= BASE;
    }
    
    inline bignum &operator += ( const bignum &x ){
        int carry = 0;
        for( int i = 0 ; i < MAXDIG ; i++ ){
            num[i] += carry + x.num[i];
            if( num[i] >= BASE )
                carry = 1, num[i] -= BASE;
            else
                carry = 0;
        }
        return (*this);
    }
    
    inline friend ostream &operator << ( ostream &out , const bignum &self ){
        int last = MAXDIG - 1;
        
        while( last >= 0 and !self.num[last] )
            --last;
        
        if( last == -1 )
            out << 0;
        else{
            out << self.num[last];
            for( int i = last - 1 ; i >= 0 ; i-- ){
                out << setw( BASELOG ) << setfill( '0' ) << self.num[i];
            }
        }
        
        return out;
    }
    
    inline friend bool operator == ( const bignum &a , const bignum &b ){
        for( int i = 0 ; i < MAXDIG ; i++ )
            if( a.num[i] != b.num[i] )
                return false;
        return true;
    }
};

int N, K;
bignum dp[MAXN];
ll lldp[MAXN];

void read(){
	//scanf("%d %d", &N, &K);
	cin >> N >> K;
}

/// Checker
ll solve2(){
    static ll dp2[MAXN][MAXN];
    
    fill( dp2[0] , dp2[0] , 0 );
    
    dp2[0][0] = 1;
    
    for( int len = 1 ; len <= N ; len++ ){
        for( int sum = 0 ; sum <= N ; sum++ ){
            dp2[len][sum] = 0;
            /// Add?
            for( int sump = 0 ; sump <= N ; sump++ ){
                int delta = sum - sump;
                /*
                if( len == 2 and sump == 2 and sum == 4 )
                    printf("WOW -> delta = %d\n", delta);
                */
                if( delta >= 2 and delta <= K )
                    dp2[len][sum] += dp2[len - 1][sump];
            }
            /// Mult (sump != 0 as we can't start from 0)
            for( int sump = 1 ; sump <= N ; sump++ ){
                int delta = sum / sump;
                if( sum % sump != 0 )
                    continue;
                /*
                if( len == 2 and sump == 2 and sum == 4 )
                    printf("WOW -> delta = %d\n", delta);
                */
                if( delta >= 2 and delta <= K )
                    dp2[len][sum] += dp2[len - 1][sump];
            }
        }
        //cerr << "dp2[" << len << "][" << N << "] = " << dp2[len][N] << endl;
    }
    
    ll answer = 0;
    
    for( int i = 0 ; i <= N ; i++ )
        answer += dp2[i][N];
    
    //cout << answer << endl;
    
    return answer;
}

void solve(){
    /// Calculate both dp's to be sure
    /// Complexity: O(N ^ 2 * MAXDIG)
    dp[0] = bignum( 1 );
    lldp[0] = 1;
    
    for( int i = 1 ; i <= N ; i++ ){
        dp[i] = bignum( 0 );
        lldp[i] = 0;
        
        for( int j = 0 ; j < i ; j++ ){ /// what's the previous sum
            int d = i - j;
            
            /**
             * Count all expression Ei = Ej * (i/j) such that i/j is a whole number between 2 and K
             */
            
            if( j > 0 and i % j == 0 and i / j >= 2 and i / j <= K ){ /// dp[i] = dp[j] * (i/j)
                dp[i] += dp[j];
                lldp[i] += lldp[j];
            }
            
            /**
             * Count all expression Ei = Ej + (i - j) such that (i - j) is between 2 and K
             */
            
            if( d >= 2 and d <= K ){ /// dp[i] = dp[j] + (i - j)
                dp[i] += dp[j];
                lldp[i] += lldp[j];
            }
        }
    }
    //printf("%d\n", dp[N]);
    /*
    if( (dp[N] == bignum( lldp[N] )) == false ){
        printf("at N = %d, K = %d\n", N, K);
        cout << lldp[N] << endl;
        cout << dp[N] << endl;
        exit(1);
    }
    */
    //cout << dp[N] << " for N = " << N << " K = " << K << endl;
    
    /*
    if( false == (dp[N] == bignum( solve2() ) )
        or false == (dp[N] == bignum( lldp[N] ) )
        or solve2() != lldp[N]
    ){
        printf("at N = %d, K = %d\n", N, K);
        cout << lldp[N] << endl;
        cout << dp[N] << endl;
        cout << solve2() << endl;
        exit(1);
    }
    */
    
    /// If the ll dp and the bignum dp are ever different ( this should not happen )
    /// ( print the bignum dp ?! )
    
    if( !( dp[N] == bignum( lldp[N] ) ) ){
        cout << dp[N] << endl;
        return;
    }
    
    cout << lldp[N] << endl;
    //solve2();
}

int main(){
	//freopen( "expression.in" , "r" , stdin );
	//freopen( "expression.out" , "w" , stdout );
	
	read();
	//init();
	/*
	for( int n = 3 ; n <= 80 ; n++ )
        for( int k = 2 ; k <= n ; k++ ){
            N = n, K = k;
            solve();
        }
	*/
	solve();
	
	return 0;
}
