/*
TASK: towers
LANG: C++
KEYW: Geometry, Dynamic Programming
*/
#include <iostream>
#include <vector>
#include <cstdio>
#include <ctime>
#include <algorithm>
#include <numeric>
#include <cmath>
#include <cstring>
#include <string>
#include <queue>
#include <set>
#define eprintf(msg, ...) 0 //fprintf( stderr , "Line #%d in %s: " msg "%c", __LINE__, __FUNCTION__, ##__VA_ARGS__, 10 )

typedef long long ll;

const ll LLINF = 1LL << 60;
const int INF = 1 << 30;
const double EPS = 1e-9;

int mycmp( double a , double b ){
	if( a - EPS > b )
		return 1;
	else if( a + EPS < b )
		return -1;
	else
		return 0;
}

using namespace std;

const int MAXN = 1 << 14;

struct tower{
    int x, y;
};

int N, K;
tower t[MAXN];

int dp[MAXN];

void read(){
	scanf("%d %d", &N, &K);
	for( int i = 0 ; i < N ; i++ )
	    scanf("%d %d", &t[i].x, &t[i].y);
}

inline bool slope_less( int x , int y , int d ){
    if( y == -1 )
        return true;
    else if( x == -1 )
        return false;
    
    /// x < y < d
    /// Returns whether the slope of (x,d) is less than the slope of (y,d)
    /// max dx = max{x} - min{x} = 3x10^4, max dy = max{y} - min{y} = 3x10^2
    /// => max dx * dy = max{dx} * max{dy} = 9x10^6
    
    int dx1 = t[d].x - t[x].x, dx2 = t[d].x - t[y].x;
    int dy1 = t[d].y - t[x].y, dy2 = t[d].y - t[y].y;
    
    eprintf("x = %d, y = %d, d = %d (%d/%d) : (%d/%d)", x, y, d, dx1, dx2, dy1, dy2);
    
    /// (dy1 / dx1) < (dy2 / dx2)
    /// dy1 * dx2 < dy2 * dx1
    
    return dy1 * dx2 < dy2 * dx1;
}

/// As:
/**
 * 1. K <= 200
 * 2. The x's are integers
 * 3. The x's are unique
 * => For each i there are O(K) possible previous towers
 * => The complexity is O(NK)
 */

void solve(){
    fill( dp , dp + N , +INF );
    
    dp[N - 1] = 1;
    
    for( int i = N - 1 ; i >= 0 ; i-- ){
        int best = -1;
        
        for( int j = i - 1 ; j >= 0 and t[i].x - t[j].x <= K ; j-- ){
            if( slope_less( j , best , i ) ){
                best = j;
                dp[j] = min( dp[j] , dp[i] + 1 );
            }
        }
    }
    
    for( int i = 0 ; i < N ; i++ ){
        eprintf("dp[%d] -> %d", i, dp[i]);
    }
    
    printf("%d\n", dp[0]);
}

int main(){
	//freopen( "towers.in" , "r" , stdin );
	//freopen( "towers.out" , "w" , stdout );
	
	read();
	//init();
	solve();
	
	return 0;
}
